@@ -51,7 +51,7 @@ class PanZoomPlugin(BasePlugin):
 
         #print(page.content)
 
-        html_page = HTMLPage(output,self.config)
+        html_page = HTMLPage(output,self.config,page)
 
         html_page.add_panzoom()
 
